==> cdktf_cdktf_provider_azurerm-4.0.7-py3-none-any.whl: package/lib/data-azurerm-private-dns-resolver-forwarding-rule/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermPrivateDnsResolverForwardingRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule#dns_forwarding_ruleset_id DataAzurermPrivateDnsResolverForwardingRule#dns_forwarding_ruleset_id}
    */
    readonly dnsForwardingRulesetId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule#id DataAzurermPrivateDnsResolverForwardingRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule#name DataAzurermPrivateDnsResolverForwardingRule#name}
    */
    readonly name: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule#timeouts DataAzurermPrivateDnsResolverForwardingRule#timeouts}
    */
    readonly timeouts?: DataAzurermPrivateDnsResolverForwardingRuleTimeouts;
}
export interface DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers {
}
export declare function dataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersToTerraform(struct?: DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers): any;
export declare class DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers | undefined;
    set internalValue(value: DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers | undefined);
    get ipAddress(): string;
    get port(): number;
}
export declare class DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersOutputReference;
}
export interface DataAzurermPrivateDnsResolverForwardingRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule#read DataAzurermPrivateDnsResolverForwardingRule#read}
    */
    readonly read?: string;
}
export declare function dataAzurermPrivateDnsResolverForwardingRuleTimeoutsToTerraform(struct?: DataAzurermPrivateDnsResolverForwardingRuleTimeoutsOutputReference | DataAzurermPrivateDnsResolverForwardingRuleTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermPrivateDnsResolverForwardingRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermPrivateDnsResolverForwardingRuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermPrivateDnsResolverForwardingRuleTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule azurerm_private_dns_resolver_forwarding_rule}
*/
export declare class DataAzurermPrivateDnsResolverForwardingRule extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_private_dns_resolver_forwarding_rule";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/private_dns_resolver_forwarding_rule azurerm_private_dns_resolver_forwarding_rule} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermPrivateDnsResolverForwardingRuleConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermPrivateDnsResolverForwardingRuleConfig);
    private _dnsForwardingRulesetId?;
    get dnsForwardingRulesetId(): string;
    set dnsForwardingRulesetId(value: string);
    get dnsForwardingRulesetIdInput(): string | undefined;
    get domainName(): string;
    get enabled(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _targetDnsServers;
    get targetDnsServers(): DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersList;
    private _timeouts;
    get timeouts(): DataAzurermPrivateDnsResolverForwardingRuleTimeoutsOutputReference;
    putTimeouts(value: DataAzurermPrivateDnsResolverForwardingRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermPrivateDnsResolverForwardingRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-7.0.1-py3-none-any.whl: package/lib/data-azurerm-private-dns-resolver-forwarding-rule/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermPrivateDnsResolverForwardingRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule#dns_forwarding_ruleset_id DataAzurermPrivateDnsResolverForwardingRule#dns_forwarding_ruleset_id}
    */
    readonly dnsForwardingRulesetId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule#id DataAzurermPrivateDnsResolverForwardingRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule#name DataAzurermPrivateDnsResolverForwardingRule#name}
    */
    readonly name: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule#timeouts DataAzurermPrivateDnsResolverForwardingRule#timeouts}
    */
    readonly timeouts?: DataAzurermPrivateDnsResolverForwardingRuleTimeouts;
}
export interface DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers {
}
export declare function dataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersToTerraform(struct?: DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers): any;
export declare class DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers | undefined;
    set internalValue(value: DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServers | undefined);
    get ipAddress(): string;
    get port(): number;
}
export declare class DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersOutputReference;
}
export interface DataAzurermPrivateDnsResolverForwardingRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule#read DataAzurermPrivateDnsResolverForwardingRule#read}
    */
    readonly read?: string;
}
export declare function dataAzurermPrivateDnsResolverForwardingRuleTimeoutsToTerraform(struct?: DataAzurermPrivateDnsResolverForwardingRuleTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermPrivateDnsResolverForwardingRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermPrivateDnsResolverForwardingRuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermPrivateDnsResolverForwardingRuleTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule azurerm_private_dns_resolver_forwarding_rule}
*/
export declare class DataAzurermPrivateDnsResolverForwardingRule extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_private_dns_resolver_forwarding_rule";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.53.0/docs/data-sources/private_dns_resolver_forwarding_rule azurerm_private_dns_resolver_forwarding_rule} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermPrivateDnsResolverForwardingRuleConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermPrivateDnsResolverForwardingRuleConfig);
    private _dnsForwardingRulesetId?;
    get dnsForwardingRulesetId(): string;
    set dnsForwardingRulesetId(value: string);
    get dnsForwardingRulesetIdInput(): string | undefined;
    get domainName(): string;
    get enabled(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _targetDnsServers;
    get targetDnsServers(): DataAzurermPrivateDnsResolverForwardingRuleTargetDnsServersList;
    private _timeouts;
    get timeouts(): DataAzurermPrivateDnsResolverForwardingRuleTimeoutsOutputReference;
    putTimeouts(value: DataAzurermPrivateDnsResolverForwardingRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermPrivateDnsResolverForwardingRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
